@@ -18,7 +18,15 @@ def cal_music_stablility(refFile=None, testFile=None):
 
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/musicStability.dll')
+
+    import platform
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/musicStability.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/musicStability.dylib')
+
     mydll.music_stability.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double,c_double,POINTER(c_double),POINTER(c_double)]
     data_format = c_double*1294
     msr = data_format()
